Learn R Programming

pseudoCure (version 1.0.0)

pseudoCure-package: pseudoCure: A pseudo-observations approach for analyzing survival data with a cure fraction

Description

A collection of easy-to-use tools for regression analysis of survival data with a cure fraction. The modeling framework is based on the Cox proportional hazards mixture cure model and the bounded cumulative hazard model. The pseudo-observations approach is utilized to assess covariate effects and embedded in the variable selection procedure.

Arguments

Author

Maintainer: Sy Han (Steven) Chiou schiou@smu.edu

Authors: